<?php

namespace Ammar\MArn\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Ammar\MArn\Interfaces\MyrteRepositoryInterface;
use Ammar\MArn\Repositories\Presenter\MyrteItemTransformer;

/**
 * Pubic API controller class.
 */
class MyrtePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Ammar\Myrte\Interfaces\MyrteRepositoryInterface $myrte
     *
     * @return type
     */
    public function __construct(MyrteRepositoryInterface $myrte)
    {
        $this->repository = $myrte;
        parent::__construct();
    }

    /**
     * Show myrte's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $myrtes = $this->repository
            ->setPresenter('\\Ammar\\MArn\\Repositories\\Presenter\\MyrteListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $myrtes['code'] = 2000;
        return response()->json($myrtes)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show myrte.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $myrte = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($myrte)) {
            $myrte         = $this->itemPresenter($module, new MyrteItemTransformer);
            $myrte['code'] = 2001;
            return response()->json($myrte)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
