<?php

namespace Ammar\MArn\Http\Controllers;
use Litepie\MArn\Http\Requests\MyrteRequest;
use Litepie\MArn\Models\Myrte;

trait MyrteWorkflow {
	
    /**
     * Workflow controller function for myrte.
     *
     * @param Model   $myrte
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MyrteRequest $request, Myrte $myrte, $step)
    {

        try {

            $myrte->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('m_arn::myrte.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/myrte/myrte/' . $myrte->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/myrte/myrte/' . $myrte->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for myrte.
     *
     * @param Model   $myrte
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Myrte $myrte, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $myrte->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('m_arn::myrte.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('m_arn::admin.myrte.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('m_arn::admin.myrte.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('m_arn::admin.myrte.message', $data)->render();

        }

    }
}