<?php

namespace Ammar\MArn\Policies;

use App\User;
use Ammar\MArn\Models\Myrte;

class MyrtePolicy
{

    /**
     * Determine if the given user can view the myrte.
     *
     * @param User $user
     * @param Myrte $myrte
     *
     * @return bool
     */
    public function view(User $user, Myrte $myrte)
    {
        if ($user->canDo('m_arn.myrte.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $myrte->user_id;
    }

    /**
     * Determine if the given user can create a myrte.
     *
     * @param User $user
     * @param Myrte $myrte
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('m_arn.myrte.create');
    }

    /**
     * Determine if the given user can update the given myrte.
     *
     * @param User $user
     * @param Myrte $myrte
     *
     * @return bool
     */
    public function update(User $user, Myrte $myrte)
    {
        if ($user->canDo('m_arn.myrte.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $myrte->user_id;
    }

    /**
     * Determine if the given user can delete the given myrte.
     *
     * @param User $user
     * @param Myrte $myrte
     *
     * @return bool
     */
    public function destroy(User $user, Myrte $myrte)
    {
        if ($user->canDo('m_arn.myrte.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $myrte->user_id;
    }

    /**
     * Determine if the given user can verify the given myrte.
     *
     * @param User $user
     * @param Myrte $myrte
     *
     * @return bool
     */
    public function verify(User $user, Myrte $myrte)
    {
        if ($user->canDo('m_arn.myrte.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('m_arn.myrte.verify') 
        && $user->is('manager')
        && $myrte->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given myrte.
     *
     * @param User $user
     * @param Myrte $myrte
     *
     * @return bool
     */
    public function approve(User $user, Myrte $myrte)
    {
        if ($user->canDo('m_arn.myrte.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
