<?php

namespace Ammar\MArn\Providers;

use Illuminate\Support\ServiceProvider;

class MArnServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'm_arn');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'm_arn');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('m_arn', function ($app) {
            return $this->app->make('Ammar\MArn\MArn');
        });

        // Bind Myrte to repository
        $this->app->bind(
            \Ammar\MArn\Interfaces\MyrteRepositoryInterface::class,
            \Ammar\MArn\Repositories\Eloquent\MyrteRepository::class
        );

        $this->app->register(\Ammar\MArn\Providers\AuthServiceProvider::class);
        $this->app->register(\Ammar\MArn\Providers\EventServiceProvider::class);
        $this->app->register(\Ammar\MArn\Providers\RouteServiceProvider::class);
        // $this->app->register(\Ammar\MArn\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['m_arn'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('ammar/m_arn.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/m_arn')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/m_arn')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
