<?php

namespace Ammar\MArn\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Ammar\MArn\Models\Myrte;

class MyrteAction
{
    /**
     * Perform the complete action.
     *
     * @param Myrte $myrte
     *
     * @return Myrte
     */
    public function complete(Myrte $myrte)
    {
        try {
            $myrte->status = 'complete';
            return $myrte->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Myrte $myrte
     *
     * @return Myrte
     */public function verify(Myrte $myrte)
    {
        try {
            $myrte->status = 'verify';
            return $myrte->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Myrte $myrte
     *
     * @return Myrte
     */public function approve(Myrte $myrte)
    {
        try {
            $myrte->status = 'approve';
            return $myrte->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Myrte $myrte
     *
     * @return Myrte
     */public function publish(Myrte $myrte)
    {
        try {
            $myrte->status = 'publish';
            return $myrte->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Myrte $myrte
     *
     * @return Myrte
     */
    public function archive(Myrte $myrte)
    {
        try {
            $myrte->status = 'archive';
            return $myrte->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Myrte $myrte
     *
     * @return Myrte
     */
    public function unpublish(Myrte $myrte)
    {
        try {
            $myrte->status = 'unpublish';
            return $myrte->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
